@@ -6,7 +6,6 @@ from common_utils_py.agreements.service_types import ServiceTypes, ServiceTypesI
 from common_utils_py.did import did_to_id
 from common_utils_py.exceptions import (
     InvalidAgreementTemplate,
-    InvalidServiceAgreementSignature,
     ServiceAgreementExists,
 )
 from contracts_lib_py.utils import add_ethereum_prefix_and_hash_msg
@@ -52,11 +51,12 @@ class Agreements:
          the ddo to use in this agreement.
         :return: tuple (agreement_id: str, signature: hex str)
         """
-        agreement_id = ServiceAgreement.create_new_agreement_id()
+        agreement_id_seed = ServiceAgreement.create_new_agreement_id()
+        agreement_id = self._keeper.agreement_manager.hash_id(agreement_id_seed, consumer_account.address)
         signature = self._sign(agreement_id, did, consumer_account, service_index)
-        return agreement_id, signature
+        return (agreement_id_seed, agreement_id), signature
 
-    def create(self, did, index, agreement_id, consumer_acc, account):
+    def create(self, did, index, agreement_id_seed, consumer_acc, account):
         """
         Execute the service agreement on-chain using keeper's ServiceAgreement contract.
 
@@ -69,7 +69,7 @@ class Agreements:
         :param did: str representation fo the asset DID. Use this to retrieve the asset DDO.
         :param index: str identifies the specific service in
          the ddo to use in this agreement.
-        :param agreement_id: 32 bytes identifier created by the consumer and will be used
+        :param agreement_id_seed: 32 bytes identifier created by the consumer and will be used
          on-chain for the executed agreement.
          conditions and their parameters values and other details of the agreement.
         :param consumer_address: ethereum account address of consumer, hex str
@@ -79,6 +79,7 @@ class Agreements:
         """
         consumer_address = consumer_acc.address
         consumer_address_real = consumer_acc.address
+        babyjub_address = None
         assert consumer_address and Web3Provider.get_web3().isChecksumAddress(
             consumer_address), f'Invalid consumer address {consumer_address}'
 
@@ -92,7 +93,7 @@ class Agreements:
         elif service.type == ServiceTypes.ASSET_ACCESS_PROOF:
             agreement_template = self._keeper.access_proof_template
             template_address = self._keeper.access_proof_template.address
-            consumer_address = consumer_acc.babyjub_address
+            babyjub_address = consumer_acc.babyjub_address
         elif service.type == ServiceTypes.CLOUD_COMPUTE:
             agreement_template = self._keeper.escrow_compute_execution_template
             template_address = self._keeper.escrow_compute_execution_template.address
@@ -114,27 +115,33 @@ class Agreements:
             logger.warning(msg)
             raise InvalidAgreementTemplate(msg)
 
-        if agreement_template.get_agreement_consumer(agreement_id) != ZERO_ADDRESS:
-            raise ServiceAgreementExists(
-                f'Service agreement {agreement_id} already exists, cannot reuse '
-                f'the same agreement id.')
-
         service_agreement = ServiceAgreement.from_service_index(index, asset)
         token_address = check_token_address(
             self._keeper, service_agreement.get_param_value_by_name('_tokenAddress'))
 
         publisher_address = Web3Provider.get_web3().toChecksumAddress(asset.publisher)
-        condition_ids = service_agreement.generate_agreement_condition_ids(
-            agreement_id, asset_id, consumer_address, self._keeper, token_address=token_address)
 
+        ((agreement_id_seed, agreement_id), *conditions) = service_agreement.generate_agreement_condition_ids(
+            agreement_id_seed, asset_id, consumer_address, self._keeper, token_address=token_address,
+            babyjub_pk=babyjub_address)
+
+        if agreement_template.get_agreement_consumer(agreement_id) != ZERO_ADDRESS:
+            raise ServiceAgreementExists(
+                f'Service agreement {agreement_id} already exists, cannot reuse '
+                f'the same agreement id.')
+
+        condition_ids = [c[0] for c in conditions]
         time_locks = service_agreement.conditions_timelocks
         time_outs = service_agreement.conditions_timeouts
 
-        if payment_involved and service_agreement.get_price() > self._keeper.token.get_token_balance(consumer_address_real):
-            return Exception(
-                f'The consumer balance is '
-                f'{self._keeper.token.get_token_balance(consumer_address_real)}. '
-                f'This balance is lower that the asset price {service_agreement.get_price()}.')
+        if payment_involved:
+            price = service_agreement.get_price()
+            consumer_balance = self._keeper.token.get_token_balance(consumer_address_real)
+            if price > consumer_balance:
+                return Exception(
+                    f'The consumer balance is '
+                    f'{consumer_balance}. '
+                    f'This balance is lower that the asset price {price}.')
 
         if service.type == ServiceTypes.NFT_SALES:
             conditions_ordered = [condition_ids[1], condition_ids[0], condition_ids[2]]
@@ -144,12 +151,12 @@ class Agreements:
             conditions_ordered = condition_ids
 
         success = agreement_template.create_agreement(
-            agreement_id,
+            agreement_id_seed,
             asset_id,
             conditions_ordered,
             time_locks,
             time_outs,
-            consumer_address_real,
+            Web3.toChecksumAddress(account.address),
             account
         )
 
@@ -231,7 +238,8 @@ class Agreements:
         publisher_address = self._keeper.did_registry.get_did_owner(asset.asset_id)
         if service_index == ServiceTypesIndices.DEFAULT_ACCESS_PROOF_INDEX:
             agreement_hash = service_agreement.get_service_agreement_hash(
-                agreement_id, asset.asset_id, consumer_account.babyjub_address, publisher_address, self._keeper
+                agreement_id, asset.asset_id, consumer_account.address, publisher_address, self._keeper,
+                babyjub_pk=consumer_account.babyjub_address
             )
         else:
             agreement_hash = service_agreement.get_service_agreement_hash(
@@ -245,20 +253,11 @@ class Agreements:
         return signature
 
     def _is_condition_fulfilled(self, agreement_id, condition_type):
-        # TODO move this method to the contracts-lib-py
-        max_retries = 5
-        sleep_time = 500
-        iteration = 0
-        while iteration < max_retries:
-            status = self.status(agreement_id)
-            condition_status = status.get('conditions').get(condition_type)
-            logger.debug(f'Condition check[  ${condition_type}  ] : + ${condition_status}')
-            if condition_status == 2:
-                return True
-            iteration = iteration + 1
-            time.sleep(sleep_time)
+        status = self.status(agreement_id)
+        condition_status = status.get('conditions').get(condition_type)
+        logger.debug(f'Condition check[  ${condition_type}  ] : + ${condition_status}')
 
-        return False
+        return condition_status == 2
 
     def _process_consumer_agreement_events(
             self, agreement_id, did, service_agreement, account,
